==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/class_item.js <==
function Item() {};

Item.COLORS = {
	'RED': '1', 'BLUE': '2', 'GREEN': '3', 'GREY': '4', 'ORANGE': '5', 'CYAN': '6', 'BROWN': '7',
	'PURPLE': '8', 'LIGHT_BLUE': '9', 'YELLOW': 'A', 'COMPLETE': 'Y', 'CLEAR': 'Z'
};

Item.open = function(id, aOtherData, aValues, sFolderType) {
	if (!sFolderType)
		sFolderType = dataSet.get("folders", [id[0], id[1], 'TYPE']);

	gui._create('gw', Mapping.getFormNameByGWType(sFolderType), '', '', id[0], id[1], id[2], aValues, aOtherData);
};

Item.create = function(sType, sAccount, sFolder) {
	// TODO	move code from obj_hmenu_basic to here
	gui.frm_main.hmenu1.__createNewGW(sType);
};

Item.createInFolder = function(sAccount, sFolder, aValues) {
	var sFolderType = dataSet.get("folders", [sAccount, sFolder, 'TYPE']);
	gui._create('gw', Mapping.getFormNameByGWType(sFolderType), '', '', sAccount, sFolder, null, aValues);
};

Item.copy = function(ids) {
	gui._create('frm_select_folder', 'frm_select_folder', '', '', 'POPUP_ITEMS::COPY_MAIL_TO', ids[0], ids[1],
		[Item.__copyOrMoveItems, ['copy', ids]], true, true, dataSet.get("folders", [ids[0], ids[1], 'TYPE']),'w'
	);
};

Item.downloadSource = function(id) {
	var aUrl = {'sid': dataSet.get('main', ['sid']), 'class': 'item', 'fullpath': id[0]+'/'+id[1]+'/'+id[2]};
	downloadItem(buildURL(aUrl));
};

Item.downloadFile = function(id) {

	var aData = WMItems.list({"aid": id[0], "fid": id[1], "iid": id[2], "values": ['EVN_ID']});
	
	aData = aData[id[0]][id[1]][id[2]];
	for (var sAtId in aData['ATTACHMENTS'])
		break;
		
	if (!Is.Defined(sAtId)) return false;

	var aUrl = {'sid':dataSet.get('main',['sid']),'class':'attachment','fullpath':id[0]+'/'+id[1]+'/'+id[2]+'/'+sAtId};
	downloadItem(buildURL(aUrl));

	return true;
};


Item.move = function(ids) {
	gui._create('frm_select_folder', 'frm_select_folder', '', '', 'POPUP_ITEMS::MOVE_MAIL_TO', ids[0], ids[1],
		[Item.__copyOrMoveItems, ['move', ids]], true, true, dataSet.get("folders", [ids[0], ids[1], 'TYPE']),'w'
	);
};

Item.remove = function(ids, bForce, oRepeating, oOriginator)
{
	storage.library('gw_others');

	var sTrashFolder;

	if (Is.Object(oRepeating)){
		var frm = gui._create('frm_confirm','frm_confirm_repeating','','', [Item.__removeWithRepeating, [ids,oRepeating]],'REPEATING_CONFIRM::TITLE_DELETE','REPEATING_CONFIRM::TEXT_DELETE');

		//return focus to originator object if any
		if (oOriginator && oOriginator._focus){
			frm.___returnFocus = function(){
				oOriginator._focus();
			};
			frm._add_destructor('___returnFocus');
		}
		
		return;
	}


	if (bForce)
		Item.__delete(ids);
	else{
		if (dataSet.get("folders",[ids[0],ids[1],'TYPE']) == 'M' && parseInt(GWOthers.getItem('MAIL_SETTINGS_GENERAL','move_to_trash'))>0 && (sTrashFolder = Path.split(GWOthers.getItem('DEFAULT_FOLDERS','trash'))[1]) != ids[1]){
			var aFolders = dataSet.get('folders');
			if (!aFolders[ids[0]][sTrashFolder]){
				sTrashFolder = Path.split(GWOthers.getDefaultValues('DEFAULT_FOLDERS')['TRASH'])[1];
				
				if (!aFolders[ids[0]][sTrashFolder])           //'TOTAL':0,
					dataSet.add('folders',[ids[0],sTrashFolder],{'NAME':sTrashFolder,'TYPE':'M','RIGHTS':'rwmd'});
			}
			Item.__copyOrMoveItems(ids[0],sTrashFolder,'move',[ids[0],ids[1],ids[2]]);
			
            //return focus to originator object if any
			if (oOriginator && oOriginator._focus)
				oOriginator._focus();
		}
		else{
			var frm = gui._create('frm_confirm','frm_confirm', '', '', [Item.__delete, [ids]],
				'CONFIRMATION::DELETE_ITEM_CONFIRMATION','CONFIRMATION::DELETE_ITEM'
			);

			//return focus to originator object if any
			if (oOriginator && oOriginator._focus){
				frm.___returnFocus = function(){
					oOriginator._focus();
				};
				frm._add_destructor('___returnFocus');
			}
		}
	}
};

Item.setColor = function(id, sColor) {
	var sOldColor = Item.getColor(id);

	if (!sOldColor || (sOldColor != sColor)) {
		// TODO rollback on error
		dataSet.add('items', id.concat(['EVNCOLOR']), sColor);
		WMItems.add(id, {'values': {'EVNCOLOR': sColor}}, 'items');
	}
};

Item.getColor = function(id) {
	return dataSet.get('items', id.concat(['EVNCOLOR']));
};

Item.hasReccurence = function(id,rcr_id) {
	if (!Is.Object(id))	return false;

	var tmpItm = dataSet.get('items',id);
	if (tmpItm.EVNCLASS == 'O') return false;

	if (!Is.Defined(rcr_id))
		rcr_id = tmpItm.EVNRCR_ID;
		
	return rcr_id?true:false;
};
Item.sendEmailTo = function(sLctEmail){
	var newMessage = new NewMessage();
		newMessage.sTo = sLctEmail;
		
	gui._create('frm_compose', 'frm_compose', '', '', newMessage);

}

Item.sendAsEmail = function(id) {

	var sFTyle = dataSet.get('folders', [id[0], id[1], 'TYPE']);
	
	if (sFTyle == 'C')
		var sName = dataSet.get('items', [id[0], id[1], id[2], 'ITMCLASSIFYAS']);
	else
		var sName = dataSet.get('items', [id[0], id[1], id[2], 'EVNTITLE']);


	var newMessage = new NewMessage();

	if (sFTyle == 'F') {
		var aData = WMItems.list({"aid": id[0], "fid": id[1], "iid": id[2], "values": ['EVN_ID']});

		aData = aData[id[0]][id[1]][id[2]];
		for (var sAtId in aData['ATTACHMENTS'])
			break;

		if (!sAtId) return false;
		// DODELAT S PAVLEM
		newMessage.aAttachments = {'attachments': [{'values': {'class': 'gwattachment', 'fullpath': id[0]+'/'+id[1]+'/'+id[2]+'/'+sAtId,
			'name': sName /*, 'size': oldMessage.getSize()*/}}]};
	}
	else
		newMessage.aAttachments = {'attachments': [{'values': {'class': 'item', 'fullpath': id[0]+'/'+id[1]+'/'+id[2],
			'name': sName+'.vcf' /*, 'size': oldMessage.getSize()*/}}]};

	gui._create('frm_compose', 'frm_compose', '', '', newMessage);
};

Item.__copyOrMoveItems = function(sDestAccount, sDestFolder, sAction, ids) {

	if (sDestAccount && sDestFolder && (sAction != 'move' || sDestAccount != ids[0] || sDestFolder != ids[1]))
	{
		// Refresh folders (folder tree)
		var aFolderProps = clone(dataSet.get('folders', [ids[0], ids[1]]), true);
		var aNewFolderProps = clone(dataSet.get('folders', [sDestAccount, sDestFolder]), true);
		var nFlag;
		
		if (aFolderProps['TYPE'] == 'M' || aFolderProps['TYPE'] == 'Q')
		{
			if (typeof aFolderProps['RECENT'] == 'undefined')
				aFolderProps['RECENT'] = 0;
				
			if (typeof aNewFolderProps != 'undefined' && !aNewFolderProps['RECENT'])
				aNewFolderProps['RECENT'] = 0;
		}

		for (var n in ids[2])
		{
			if (typeof aNewFolderProps != 'undefined')
			{
				//dataSet.add('folders',[sDestAccount,sDestFolder,'TOTAL'],++aNewFolderProps['TOTAL'],true);
	
				if (aFolderProps['TYPE'] == 'M' || aFolderProps['TYPE'] == 'Q')
					if (!(nFlag = WMItems.getFlag([ids[0],ids[1],ids[2][n]],'SEEN','items')))
						dataSet.add('folders', [sDestAccount, sDestFolder, 'RECENT'], (++aNewFolderProps['RECENT']).toString(), true);
			}

			if (sAction == 'move')
			{
				//dataSet.add('folders', [ids[0], ids[1], 'TOTAL'], --aFolderProps['TOTAL'], true);

				if (aFolderProps['TYPE'] == 'M' || aFolderProps['TYPE'] == 'Q')
					if (!nFlag)
						dataSet.add('folders', [ids[0], ids[1], 'RECENT'], (--aFolderProps['RECENT']).toString(), true);
			}
		}
		dataSet.update('folders');

		switch(sAction)
		{
			case 'copy':
				//Async copy items and refresh folders (folder tree)
				WMItems.copy({'aid':ids[0],'fid':ids[1],'iid':ids[2],'account':sDestAccount,'folder':sDestFolder},'items','','folders');
				break;

			case 'move': // sinchronous

				if (sDestAccount != ids[0] || sDestFolder != ids[1])
				{
					/*
					//Async move items and refresh folders (folder tree)
					var aHandler = null;
					if (!Item.__removeFromDataset(ids))
						aHandler = [Item.__refreshView, [ids]];
						WMItems.move({'aid':ids[0],'fid':ids[1],'iid':ids[2],'account':sDestAccount,'folder':sDestFolder},'items','','folders',aHandler);
					*/

                    //synchro move
					WMItems.move({'aid':ids[0],'fid':ids[1],'iid':ids[2],'account':sDestAccount,'folder':sDestFolder},'items','','folders');
                    Item.__removeFromDataset(ids);
/*
					if (!Item.__removeFromDataset(ids))
						Item.__refreshView(ids);        // pokud bude blbnout move u EMAILU tak zakomentovat!!
*/
				}
				break;
		}
	}
};

Item.__removeWithRepeating = function(iState, ids, oRepeating,oOriginator) {
	var aValues = {};

	switch(iState.toString()){
	case '2':
		aValues.EXPFOLLOWING = 'true';
	case '0':
		aValues.EXPDATE = oRepeating['EVNSTARTDATE'];
		WMItems.remove({'aid':ids[0],'fid':ids[1],'iid':ids[2],'values':[aValues]},'items','','folders',[Item.__refreshView, [ids,true]]);
		break;
	default:
		Item.__delete(ids);
	}
};

Item.__delete = function(ids) {

	// DELETE SELECTION 2
	for (var i in ids[2])
		 if (ids[2][i].indexOf('|')>-1)
		 	delete ids[2][i];

	if (!count(ids[2])) return;

	// Refresh folders (folder tree)
	var aFolderProps = clone(dataSet.get('folders',[ids[0],ids[1]]),true);
	
	if (aFolderProps['TYPE'] == 'M')
		if (typeof aFolderProps['RECENT'] == 'undefined')
			aFolderProps['RECENT'] = 0;

	for(var n in ids[2]){
		//dataSet.add('folders',[ids[0],ids[1],'TOTAL'],--aFolderProps['TOTAL'],true);

		if (aFolderProps['TYPE'] == 'M')
			if (!WMItems.getFlag(makeIDFromIDS(ids,n),'SEEN','items'))
				dataSet.add('folders',[ids[0],ids[1],'RECENT'],(--aFolderProps['RECENT']>0?aFolderProps['RECENT']:0).toString(),true);
	}
	dataSet.update('folders');

	WMItems.remove({'aid':ids[0],'fid':ids[1],'iid':ids[2]},'items','','folders');

	// Async remove items
	if(!Item.__removeFromDataset(ids))
		Item.__refreshView(ids);
};

Item.__removeFromDataset = function(ids)
{
	var sFolType = dataSet.get('folders',[ids[0],ids[1],'TYPE']);

	// Vymazání položek z datasetu
	var n = 0;
	for(var i in ids[2]){
		if (dataSet.remove('items', makeIDFromIDS(ids, i), true))
			n++;
	}

	// Correct Total (Count)
	var iTotal	= dataSet.get("items",[ids[0],ids[1],'/']);
	if (typeof iTotal != 'undefined')
		dataSet.add("items",[ids[0],ids[1],'/'],parseInt(iTotal)-n,true);

	// Mažeme maily nebo quarantine?
	if (sFolType == 'M' || sFolType == 'Q'){
		var sIt = dataSet.get('active_mails',[ids[0],ids[1]]);

		// Mažeme mail, který byl aktivní pro náš folder?
		if (inArray(ids[2], sIt) > -1){
			dataSet.remove('active_mails',[ids[0],ids[1]]);
			dataSet.remove('mailview');
		}
	}

	if (sFolType != 'E' || dataSet.get('datagrid_views',[ids[0],ids[1]])['view'] == 'list_view'){
		dataSet.update('items');
		return true;
	}
	else
		// indicate that the view needs to be updated from the server
		return false;
};

Item.__refreshView = function(ids,bNoRefresh) {
	var aActive = getPathFromDataset('items');
	if (aActive[0] == ids[0] && aActive[1] == ids[1])
		gui.frm_main._selectView({'aid':ids[0],'fid':ids[1]},null,(bNoRefresh?false:true),null,true);
};

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/class_item.js <==
function Item() {};

Item.COLORS = {
	'RED': '1', 'BLUE': '2', 'GREEN': '3', 'GREY': '4', 'ORANGE': '5', 'CYAN': '6', 'BROWN': '7',
	'PURPLE': '8', 'LIGHT_BLUE': '9', 'YELLOW': 'A', 'COMPLETE': 'Y', 'CLEAR': 'Z'
};

Item.NOTE_COLORS = {
     'CLEAR': 'Z','BLUE': '1', 'GREEN': '2', 'RED': '3', 'WHITE': '5', 'YELLOW': '6'
};

Item.open = function(id, aOtherData, aValues, sFolderType) {
	if (!sFolderType)
		sFolderType = dataSet.get("folders", [id[0], id[1], 'TYPE']);

	gui._create('gw', Mapping.getFormNameByGWType(sFolderType), '', '', id[0], id[1], id[2], aValues, aOtherData);
};

Item.create = function(sType, sAccount, sFolder) {
	// TODO	move code from obj_hmenu_basic to here
	gui.frm_main.hmenu1.__createNewGW(sType);
};

Item.createInFolder = function(sAccount, sFolder, aValues) {
	var sFolderType = dataSet.get("folders", [sAccount, sFolder, 'TYPE']);
	gui._create('gw', Mapping.getFormNameByGWType(sFolderType), '', '', sAccount, sFolder, null, aValues);
};

Item.copy = function(ids) {
	gui._create('frm_select_folder', 'frm_select_folder', '', '', 'POPUP_ITEMS::COPY_MAIL_TO', ids[0], ids[1],
		[Item.__copyOrMoveItems, ['copy', ids]], true, true, dataSet.get("folders", [ids[0], ids[1], 'TYPE']),'w'
	);
};

Item.downloadSource = function(id,ext) {
	var aUrl = {'sid': dataSet.get('main', ['sid']), 'class': 'item'+(ext || ''), 'fullpath': id[0]+'/'+id[1]+'/'+id[2]};
	downloadItem(buildURL(aUrl));
};

Item.downloadFile = function(id) {

	var aData = WMItems.list({"aid": id[0], "fid": id[1], "iid": id[2], "values": ['EVN_ID']});
		aData = aData[id[0]][id[1]][id[2]];
		
	for (var sAtId in aData['ATTACHMENTS'])
		break;
		
	if (!Is.Defined(sAtId)) return false;

	var aUrl = {'sid':dataSet.get('main',['sid']),'class':'attachment','fullpath':id[0]+'/'+id[1]+'/'+id[2]+'/'+sAtId};
	downloadItem(buildURL(aUrl));

	return true;
};


Item.move = function(ids) {
	gui._create('frm_select_folder', 'frm_select_folder', '', '', 'POPUP_ITEMS::MOVE_MAIL_TO', ids[0], ids[1],
		[Item.__copyOrMoveItems, ['move', ids]], true, true, dataSet.get("folders", [ids[0], ids[1], 'TYPE']),'w'
	);
};

/**
 * oOriginator - object which will be focused after execution
 * iNext - originator next value
 */
Item.remove = function(ids, bForce, oRepeating, oOriginator, iNext)
{
	storage.library('gw_others');

	var sTrashFolder;

	if (Is.Object(oRepeating)){
		var frm = gui._create('frm_confirm','frm_confirm_repeating','','', [Item.__removeWithRepeating, [ids,oRepeating]],'REPEATING_CONFIRM::TITLE_DELETE','REPEATING_CONFIRM::TEXT_DELETE');

		//return focus to originator object if any
		if (oOriginator && oOriginator._focus){
			frm.___returnFocus = function(){
				oOriginator._focus();
			};
			frm._add_destructor('___returnFocus');
		}
		
		return;
	}


	if (bForce)
		Item.__delete(ids);
	else
	if (dataSet.get("folders",[ids[0],ids[1],'TYPE']) == 'M' && parseInt(GWOthers.getItem('MAIL_SETTINGS_GENERAL','move_to_trash'))>0 && (sTrashFolder = Path.split(GWOthers.getItem('DEFAULT_FOLDERS','trash'))[1]) != ids[1]){

		var aFolders = dataSet.get('folders');
		if (!aFolders[ids[0]][sTrashFolder])
			dataSet.add('folders',[ids[0],sTrashFolder],{'NAME':sTrashFolder,'TYPE':'M','RIGHTS':'rwmd'});

		Item.__copyOrMoveItems(ids[0],sTrashFolder,'move',[ids[0],ids[1],ids[2]]);

        //return focus to originator object if any
		if (oOriginator){
			if (oOriginator._focus)
				oOriginator._focus();
			if (typeof iNext != 'undefined')
				oOriginator._value([iNext]);
		}
	}
	else{
		var frm = gui._create('frm_confirm','frm_confirm', '', '', [Item.__delete, [ids,oOriginator,iNext]],
			'CONFIRMATION::DELETE_ITEM_CONFIRMATION','CONFIRMATION::DELETE_ITEM'
		);

		//return focus to originator object if any
		if (oOriginator && oOriginator._focus){
			frm.___returnFocus = function(){
				oOriginator._focus();
			};
			frm._add_destructor('___returnFocus');
		}
	}
};

Item.setColor = function(id, sColor) {
	var sOldColor = Item.getColor(id);

	if (!sOldColor || (sOldColor != sColor)) {
		// TODO rollback on error
		dataSet.add('items', id.concat(['EVNCOLOR']), sColor);
		WMItems.add(id, {'values': {'EVNCOLOR': sColor}}, 'items');
	}
};

Item.getColor = function(id) {
	return dataSet.get('items', id.concat(['EVNCOLOR']));
};

Item.hasReccurence = function(id,rcr_id) {
	if (!Is.Object(id))	return false;

	var tmpItm = dataSet.get('items',id);
	if (tmpItm.EVNCLASS == 'O') return false;

	if (!Is.Defined(rcr_id))
		rcr_id = tmpItm.EVNRCR_ID;
		
	return rcr_id?true:false;
};
Item.sendEmailTo = function(sLctEmail){
	var newMessage = new NewMessage();
		newMessage.sTo = sLctEmail;
		
	gui._create('frm_compose', 'frm_compose', '', '', newMessage);

}

Item.sendAsEmail = function(id) {

	var sFTyle = dataSet.get('folders', [id[0], id[1], 'TYPE']);
	
	if (sFTyle == 'C')
		var sName = dataSet.get('items', [id[0], id[1], id[2], 'ITMCLASSIFYAS']);
	else
		var sName = dataSet.get('items', [id[0], id[1], id[2], 'EVNTITLE']);


	var newMessage = new NewMessage();

	if (sFTyle == 'F') {
		var aData = WMItems.list({"aid": id[0], "fid": id[1], "iid": id[2], "values": ['EVN_ID']});

		aData = aData[id[0]][id[1]][id[2]];
		for (var sAtId in aData['ATTACHMENTS'])
			break;

		if (!sAtId) return false;
		// DODELAT S PAVLEM
		newMessage.aAttachments = {'attachments': [{'values': {'class': 'gwattachment', 'fullpath': id[0]+'/'+id[1]+'/'+id[2]+'/'+sAtId,
			'name': sName /*, 'size': oldMessage.getSize()*/}}]};
	}
	else
		newMessage.aAttachments = {'attachments': [{'values': {'class': 'item', 'fullpath': id[0]+'/'+id[1]+'/'+id[2],
			'name': sName+'.vcf' /*, 'size': oldMessage.getSize()*/}}]};

	gui._create('frm_compose', 'frm_compose', '', '', newMessage);
};

Item.__copyOrMoveItems = function(sDestAccount, sDestFolder, sAction, ids) {

	if (sDestAccount && sDestFolder && (sAction != 'move' || sDestAccount != ids[0] || sDestFolder != ids[1]))
	{
		// Refresh folders (folder tree)
		var aFolderProps = clone(dataSet.get('folders', [ids[0], ids[1]]), true);
		var aNewFolderProps = clone(dataSet.get('folders', [sDestAccount, sDestFolder]), true);
		var nFlag;
		
		if (aFolderProps){
			if (aFolderProps['TYPE'] == 'M' || aFolderProps['TYPE'] == 'Q'){
				if (typeof aFolderProps['RECENT'] == 'undefined')
					aFolderProps['RECENT'] = 0;

				if (typeof aNewFolderProps != 'undefined' && !aNewFolderProps['RECENT'])
					aNewFolderProps['RECENT'] = 0;
			}

			for (var n in ids[2])
			{
				if (typeof aNewFolderProps != 'undefined')
					if (aFolderProps['TYPE'] == 'M' || aFolderProps['TYPE'] == 'Q')
						if (!(nFlag = WMItems.getFlag([ids[0],ids[1],ids[2][n]],'SEEN','items')))
							dataSet.add('folders', [sDestAccount, sDestFolder, 'RECENT'], (++aNewFolderProps['RECENT']).toString(), true);

				if (sAction == 'move')
					if (aFolderProps['TYPE'] == 'M' || aFolderProps['TYPE'] == 'Q')
						if (!nFlag)
							dataSet.add('folders', [ids[0], ids[1], 'RECENT'], (--aFolderProps['RECENT']).toString(), true);
			}
			dataSet.update('folders');
		}

		switch(sAction)
		{
			case 'copy':
				//Async copy items and refresh folders (folder tree)
				WMItems.copy({'aid':ids[0],'fid':ids[1],'iid':ids[2],'account':sDestAccount,'folder':sDestFolder},'items','','folders',[Item.__refreshView, [[sDestAccount,sDestFolder],true]]);
				break;

			case 'move': // sinchronous

				if (sDestAccount != ids[0] || sDestFolder != ids[1])
				{
					/*
					//Async move items and refresh folders (folder tree)
					var aHandler = null;
					if (!Item.__removeFromDataset(ids))
						aHandler = [Item.__refreshView, [ids]];
						WMItems.move({'aid':ids[0],'fid':ids[1],'iid':ids[2],'account':sDestAccount,'folder':sDestFolder},'items','','folders',aHandler);
					*/

					//synchro move
					WMItems.move({'aid':ids[0],'fid':ids[1],'iid':ids[2],'account':sDestAccount,'folder':sDestFolder},'items','','folders');

					if (!Item.__removeFromDataset(ids))
						Item.__refreshView(ids,true);
				}
				break;
		}
	}
};

Item.__removeWithRepeating = function(iState, ids, oRepeating,oOriginator) {
	var aValues = {};

	switch(iState.toString()){
	case '2':
		aValues.EXPFOLLOWING = 'true';
	case '0':
		aValues.EXPDATE = oRepeating['EVNSTARTDATE'];
		WMItems.remove({'aid':ids[0],'fid':ids[1],'iid':ids[2],'values':[aValues]},'items','','folders',[Item.__refreshView, [ids,true]]);
		break;
	default:
		Item.__delete(ids);
	}
};

/**
 * optional oOriginator,iNext (for DataFrid purpose)
 **/
Item.__delete = function(ids,oOriginator,iNext) {

	// DELETE SELECTION 2
	for (var i in ids[2])
		 if (ids[2][i].indexOf('|')>-1)
		 	delete ids[2][i];

	if (oOriginator && oOriginator._focus)
		oOriginator._focus();

	if (!count(ids[2])) return;

	// Refresh folders (folder tree)
	var aFolderProps = clone(dataSet.get('folders',[ids[0],ids[1]]),true);
	if (aFolderProps){
		if (aFolderProps['TYPE'] == 'M' || aFolderProps['TYPE'] == 'R')
			if (typeof aFolderProps['RECENT'] == 'undefined')
				aFolderProps['RECENT'] = 0;

		for(var n in ids[2]){
			//dataSet.add('folders',[ids[0],ids[1],'TOTAL'],--aFolderProps['TOTAL'],true);

			if (aFolderProps['TYPE'] == 'M' || aFolderProps['TYPE'] == 'R')
				if (!WMItems.getFlag(makeIDFromIDS(ids,n),'SEEN','items'))
					dataSet.add('folders',[ids[0],ids[1],'RECENT'],(--aFolderProps['RECENT']>0?aFolderProps['RECENT']:0).toString(),true);
		}

		dataSet.update('folders');
	}

	WMItems.remove({'aid':ids[0],'fid':ids[1],'iid':ids[2]},'items','','folders');

	if (oOriginator  && typeof iNext != 'undefined')
		oOriginator._value([iNext]);

	// Async remove items
	if(!Item.__removeFromDataset(ids))
		Item.__refreshView(ids);
};

Item.__removeFromDataset = function(ids)
{
	var sFolType = dataSet.get('folders',[ids[0],ids[1],'TYPE']);

	// Vymazání položek z datasetu
	var n = 0;
	for(var i in ids[2]){
		if (dataSet.remove('items', makeIDFromIDS(ids, i), true))
			n++;
	}

	// Correct Total (Count)
	var iTotal	= dataSet.get("items",[ids[0],ids[1],'/']);
	if (typeof iTotal != 'undefined')
		dataSet.add("items",[ids[0],ids[1],'/'],parseInt(iTotal)-n,true);

	// Mažeme maily, RSS nebo quarantine?
	if (sFolType == 'M' || sFolType == 'R' || sFolType == 'Q'){
		var sIt = dataSet.get('active_mails',[ids[0],ids[1]]);

		// Mažeme mail, který byl aktivní pro náš folder?
		if (inArray(ids[2], sIt) > -1){
			dataSet.remove('active_mails',[ids[0],ids[1]]);
			dataSet.remove('mailview');
		}
	}

	if (sFolType != 'E' ||  dataSet.get('datagrid_views',[ids[0],ids[1]])['view'] == 'list_view'){
		dataSet.update('items');
		return true;
	}
	else
		// indicate that the view needs to be updated from the server
		return false;
};

Item.__refreshView = function(ids,bNoRefresh) {
	var aActive = getPathFromDataset('items');
	if (aActive && aActive[0] == ids[0] && aActive[1] == ids[1])
		gui.frm_main._selectView({'aid':ids[0],'fid':ids[1]},null,false,null,(bNoRefresh?false:true));
};
